pub struct ProvidedDefaultUnstable {
pub feature: String,
}Expand description
Information about an unstable default provided by a trait item.
Example unstable defaults include:
- a stable trait function or method whose body is not stable
- a stable trait associated type or const whose default value is not stable
Fields
feature: StringThe feature that must be enabled to use the provided default.