pub struct Stability {
pub feature: String,
pub level: StabilityLevel,
}Expand description
Stability information for an item.
In Item::stability, this refers to regular item stability: whether the item is
stable or unstable as represented by the #[stable] or #[unstable] attributes.
In Item::const_stability, this refers to using the item in const contexts,
as represented by #[rustc_const_stable] or #[rustc_const_unstable].
Fields
feature: StringThe feature associated with this stability record.
For unstable items, this is the feature gate associated with the item. For stable items, this is the historical label recorded when the item was stabilized.
level: StabilityLevelTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Stability
impl<'de> Deserialize<'de> for Stability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Stability
impl StructuralPartialEq for Stability