pub struct Stability {
pub feature: String,
pub level: StabilityLevel,
}Expand description
Stability information for an item.
This only refers to regular item stability: whether the item is stable or unstable
as represented by the #[stable] or #[unstable] attributes.
Const stability and default-body stability are different things and not captured here.
Fields
feature: StringThe stability feature associated with this item.
For unstable items, this is the feature gate associated with the item. For stable items, this is the historical label recorded when the item was stabilized.
level: StabilityLevelTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Stability
impl<'de> Deserialize<'de> for Stability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Stability
impl StructuralPartialEq for Stability